*cd ""

set matsize 1000
use "Master.dta", clear

label define country 1 "USA" 2 "GER" 3 "DEN" 4 "KOREA" 5 "BE"
label values country country
gen N= (N1 +N2 +N3+ N4 +N5+ N6+ N7+ N8 +N9+ N10+ N11+ N12 +N13+ N14+ N15)/15
gen NC1=(N6 + N7 + N12)/3
gen NC2=(N1+N10+N2)/3
gen NC3=(N3+N13+N9+N11+N5+N4)/6
gen NC4=(N8)
gen NC5=(N14+N15)/2

gen SN=(N4+N6+N7+N9+N11)/5								// Generate self-nudge average
gen ON=(N1+N2+N3+N5+N8+N10+N12+N13+N14+N15)/10			// Generate other-nudge average

gen bmi=(weight)/((height/100)*(height/100))
glo exo  i.country i.gender age yos city i.married noc income i.money_left i.car politics i.native  i.smoke alcohol meat ///
 health swb job_satisfaction i.friends trust_ggen trust_pgen environment health_concern health_concernf markets risk /// 
 freedom  trustscore_inst trustscore_priv infoscore bmi
 

 
 
 drop if bmi>=50 | bmi<12
 replace WEIGHT=1 if WEIGHT==.
 

 
 
 
 
 
 * Desctreptives
 
   glo des country gender age yos N1 N2 N3 N4 N5 N6 N7 N8 N9 N10 N11 N12 N13 N14 N15 city married noc ///
 income money_left car politics native weight smoke alcohol meat health swb job_satisfaction friends ///
 trust_ggen trust_pgen environment health_concern health_concernf markets risk freedom  height ///
 trustscore_inst trustscore_priv infoscore N NC1 NC2 NC3 NC4 NC5 bmi
 
 makematrix m1, from(r(N) r(mean) r(sd)) vector: sum $x_des 
 
 xml_tab m1 , save("des.xml") replace
 
 
 
 *Bar graphs
 
 set scheme tufte
 
 forvalue i=1(1)15 {
 
	replace N`i'=N`i'*100
	
	}
	
forvalues k=1(1)15 {
	
 cibar N`k' [pweight=WEIGHT], over1(country) bargap(10) blgap(-40) blp(south) blsize(vsmall) baropt(fcolor(gs15) fi(90)) barlabel(on) gr(ytitle("Approval in Percent") xtitle("95% CI") legend(off) yscale(r(0 100)) title("Nudge: Childhood obesity") ///
 ylabel(0 20 40 60 80 100)  xmlabel(1.10 "USA" 2.20 "GER" 3.30 "DEN" 4.40 "KOREA" 5.50 "BE" ))
 graph save N`k', replace
 }
 
 
 
 
 
 
 
 
 
 
 

 * Analysis
 
 
 
 foreach y in "N" "NC1" "NC2" "NC3" "NC4" "NC5" {
 
		 reg `y' $exo [pweight=WEIGHT], vce(robust)
		est store r_`y'
		}
		
		
		
esttab r_N r_NC1 r_NC2 r_NC3 r_NC4 r_NC5 using Table1.rtf , ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 		


****Self and other nudges***********************+
reg SN $exo [pweight=WEIGHT], vce(robust)
est store n_1
reg ON $exo [pweight=WEIGHT], vce(robust)
est store n_2

esttab n_1 n_2 using Self.rtf , ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 
*************************************************
scalar k=[_N]*5
scalar rv =[_N]
set obs `=k'


gen de=.
gen NC=.

scalar sta=1
scalar en_d=5385


scalar da=1

foreach y in "NC1" "NC2" "NC3" "NC4" "NC5" {
	
	
	replace de=`=da' in `=sta'/`=en_d'
	scalar da=da+1
	}

	
	
scalar rv_1=1
scalar rv_2=5385

	foreach y in "NC1" "NC2" "NC3" "NC4" "NC5" {
	
		scalar rv_3=1
		forvalues i=`=rv_1'(1)`=rv_2' {
			replace NC=`y'[`=rv_3'] in `i'
			scalar rv_3=rv_3+1
			}
		scalar rv_1=rv_1+5385
		scalar rv_2=rv_2+5385

	}
	
replace NC=NC*100
set scheme tufte
cibar NC, over1(de) bargap(10) blgap(-40) blp(north) blorientation(vertical) blsize(vsmall)  ///
baropt(fcolor(gs15) fi(90)) barlabel(on) gr(ytitle("Approval in percent") xtitle("Nudge Cluster") legend(off) yscale(r(0 100))  ylabel(0 20 40 60 80 100) )



**********************Approval by Nudge Cluster*********************************

		
		
foreach y in "N1" "N2" "N3" "N4" "N5" "N6" "N7" "N8" "N9" "N10" "N11" "N12" "N13" "N14" "N15" {

	qui logit `y' $exo [pweight=WEIGHT], vce(robust)
	est store r_`y' 
	}
	

	
	

esttab  r_N6 r_N7 r_N12 using cluster1.rtf, ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 		


esttab  r_N1 r_N10 r_N2 using cluster2.rtf, ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 

esttab  r_N3 r_N13 r_N9 r_N11 r_N5 r_N4 using cluster3.rtf, ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 


esttab r_N8  using cluster4.rtf, ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 


esttab r_N14 r_N15  using cluster5.rtf, ar2(3) se(3) star(* 0.1 ** 0.05 *** 0.01) b(%6.4f) nogaps replace varwidth(20) ///
keep () ///
refcat ( ) ///
drop ( 0.gender 0.married 0.money_left 0.car 0.native 0.smoke 0.friends 1.country) ///
nodep coeflabels(2.country "GER" 3.country "DEN" 4.country "KOREA" 5.country "BE" 1.gender "Male" 1.married "Married" 1.money_left "Money left" 1.car "Car" 1.native  "Native" 1.smoke "Smoke" 1.friends  "Friends") ///
mtitle () ///
title()   ///
nonote note("Robust standard errors in parentheses. * p < 0.1, ** p < 0.05, *** p < 0.01." ) 




foreach y in "N1" "N2" "N3" "N4" "N5" "N6" "N7" "N8" "N9" "N10" "N11" "N12" "N13" "N14" "N15" {

	qui logit `y' $exo [pweight=WEIGHT], vce(robust)
	qui margins, at(trustscore_inst=(10 20 30 40 50 60 70)) atmeans
	qui marginsplot, ytitle("P(approval=1)") xtitle("Trust in institutions") title("`y'")
	graph export `y'_trust.png, replace
}


foreach y in "N1" "N2" "N3" "N4" "N5" "N6" "N7" "N8" "N9" "N10" "N11" "N12" "N13" "N14" "N15" {

	qui logit `y' $exo [pweight=WEIGHT], vce(robust)
	qui margins, at(environment=(1 2 3 4 5 6 7)) atmeans
	qui marginsplot, ytitle("P(approval=1)") xtitle("Environmental concern") title("`y'")
	graph export `y'_environment.png, replace
}



 set scheme tufte
 
 forvalue i=1(1)15 {
 
	replace N`i'=N`i'*100
	
	}
	
forvalue i=1(1)5 {
 
	replace NC`i'=NC`i'*100
	
	}
	replace N=N*100

	

	
	
	
cibar N [pweight=WEIGHT], over1(gender) over2(environment) bargap(10) blgap(-40) blp(north) blorientation(vertical) blsize(vsmall)  ///
baropt(fcolor(gs15) fi(90)) barlabel(on) gr(ytitle("Approval in percent") xtitle("Environmental concern") legend(off) yscale(r(0 100))  ylabel(0 20 40 60 80 100) )
graph save N_environment, replace
*title("Nudge approval conditional by environmental concern")

bysort trustscore_inst: egen tmeanN=mean(N)
bysort trustscore_inst: egen tmeanNf=mean(N) if gender==0
bysort trustscore_inst: egen tmeanNm=mean(N) if gender==1
twoway line tmeanNf trustscore_inst, ytitle("Approval in percent") , legend(lab(1 "female"))  || line tmeanNm trustscore_inst, legend(lab(2 "male"))
graph save N_trust, replace


gen tr=.
scalar h=1
forvalues i=10(5)70 {
	
	scalar k=`i'+5
	replace tr=`=h' if trustscore_inst>=`i' & trustscore_inst<`=k'
	scalar h=h+1
}
bysort tr: egen tmeanN=mean(N)
bysort tr: egen tmeanNf=mean(N) if gender==0
bysort tr: egen tmeanNm=mean(N) if gender==1
twoway line tmeanNf trustscore_inst, ytitle("Approval in percent") , legend(lab(1 "female"))  || line tmeanNm trustscore_inst, legend(lab(2 "male")) yscale(range(0 20 40 60 80 100)) ylabel(0 20 40 60 80 100)
graph save N_trust, replace










forvalues k=1(1)15 {
	
 cibar N`k' [pweight=WEIGHT], over1(country) bargap(10) blgap(-40) blp(south) blsize(vsmall) baropt(fcolor(gs15) fi(90)) barlabel(on) gr(ytitle("Approval in Percent") xtitle("95% CI") legend(off) yscale(r(0 100)) title("Nudge: Childhood obesity") ///
 ylabel(0 20 40 60 80 100)  xmlabel(1.10 "USA" 2.20 "GER" 3.30 "DEN" 4.40 "KOREA" 5.50 "BE" ))
 graph save N`k', replace
	



	
	matrix ap=J(21,4,.)
	
forvalues t=1(1)4 {
	
	forvalues i=1(1)15 {
		
		qui mean N`i' [pweight=WEIGHT] if country==`t'
		
		qui matrix ap[`i',`t']=e(b)
		
		}
	}

forvalues t=1(1)4 {

	scalar k=16
	
	forvalues i=1(1)5 {
	
		qui mean NC`i' [pweight=WEIGHT] if country==`t'
		
		qui matrix ap[`=k',`t']=e(b)
		
		scalar k=k+1
		
		}
	}

forvalues t=1(1)4 {

	qui mean N [pweight=WEIGHT] if country==`t'
	
	qui matrix ap[21,`t']=e(b)
	
	}

xml_tab ap , save("Veerle.xml") replace
